==> libreoffice-fresh-sdk-5.3.0-2-armv6h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/classes_11.js <==
var searchData=
[
  ['radiobutton',['RadioButton',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1RadioButton.html',1,'com::sun::star::form::component']]],
  ['radiobutton',['RadioButton',['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1RadioButton.html',1,'com::sun::star::form::control']]],
  ['rangehighlighter',['RangeHighlighter',['../servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1RangeHighlighter.html',1,'com::sun::star::chart2::data']]],
  ['rangehighlightlistener',['RangeHighlightListener',['../servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1RangeHighlightListener.html',1,'com::sun::star::chart2::data']]],
  ['rangeselectionarguments',['RangeSelectionArguments',['../servicecom_1_1sun_1_1star_1_1sheet_1_1RangeSelectionArguments.html',1,'com::sun::star::sheet']]],
  ['rangeselectionevent',['RangeSelectionEvent',['../structcom_1_1sun_1_1star_1_1sheet_1_1RangeSelectionEvent.html',1,'com::sun::star::sheet']]],
  ['readonlyaccess',['ReadOnlyAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1ReadOnlyAccess.html',1,'com::sun::star::configuration']]],
  ['readwriteaccess',['ReadWriteAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1ReadWriteAccess.html',1,'com::sun::star::configuration']]],
  ['realbeziersegment2d',['RealBezierSegment2D',['../structcom_1_1sun_1_1star_1_1geometry_1_1RealBezierSegment2D.html',1,'com::sun::star::geometry']]],
  ['realpoint2d',['RealPoint2D',['../structcom_1_1sun_1_1star_1_1geometry_1_1RealPoint2D.html',1,'com::sun::star::geometry']]],
  ['realrectangle2d',['RealRectangle2D',['../structcom_1_1sun_1_1star_1_1geometry_1_1RealRectangle2D.html',1,'com::sun::star::geometry']]],
  ['realrectangle3d',['RealRectangle3D',['../structcom_1_1sun_1_1star_1_1geometry_1_1RealRectangle3D.html',1,'com::sun::star::geometry']]],
  ['realsize2d',['RealSize2D',['../structcom_1_1sun_1_1star_1_1geometry_1_1RealSize2D.html',1,'com::sun::star::geometry']]],
  ['recentfunctions',['RecentFunctions',['../servicecom_1_1sun_1_1star_1_1sheet_1_1RecentFunctions.html',1,'com::sun::star::sheet']]],
  ['recipientinfo',['RecipientInfo',['../structcom_1_1sun_1_1star_1_1ucb_1_1RecipientInfo.html',1,'com::sun::star::ucb']]],
  ['rectangle',['Rectangle',['../structcom_1_1sun_1_1star_1_1awt_1_1Rectangle.html',1,'com::sun::star::awt']]],
  ['rectangleshape',['RectangleShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1RectangleShape.html',1,'com::sun::star::drawing']]],
  ['redlineportion',['RedlinePortion',['../servicecom_1_1sun_1_1star_1_1text_1_1RedlinePortion.html',1,'com::sun::star::text']]],
  ['referencecolumn',['ReferenceColumn',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1ReferenceColumn.html',1,'com::sun::star::sdbcx']]],
  ['referencemark',['ReferenceMark',['../servicecom_1_1sun_1_1star_1_1text_1_1ReferenceMark.html',1,'com::sun::star::text']]],
  ['referencemarks',['ReferenceMarks',['../servicecom_1_1sun_1_1star_1_1text_1_1ReferenceMarks.html',1,'com::sun::star::text']]],
  ['referencepageget',['ReferencePageGet',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ReferencePageGet.html',1,'com::sun::star::text::textfield']]],
  ['referencepageset',['ReferencePageSet',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ReferencePageSet.html',1,'com::sun::star::text::textfield']]],
  ['registryservicemanager',['RegistryServiceManager',['../servicecom_1_1sun_1_1star_1_1lang_1_1RegistryServiceManager.html',1,'com::sun::star::lang']]],
  ['regressioncurve',['RegressionCurve',['../servicecom_1_1sun_1_1star_1_1chart2_1_1RegressionCurve.html',1,'com::sun::star::chart2']]],
  ['regressioncurveequation',['RegressionCurveEquation',['../servicecom_1_1sun_1_1star_1_1chart2_1_1RegressionCurveEquation.html',1,'com::sun::star::chart2']]],
  ['regressionequation',['RegressionEquation',['../servicecom_1_1sun_1_1star_1_1chart2_1_1RegressionEquation.html',1,'com::sun::star::chart2']]],
  ['relationdesign',['RelationDesign',['../servicecom_1_1sun_1_1star_1_1sdb_1_1RelationDesign.html',1,'com::sun::star::sdb']]],
  ['relativeposition',['RelativePosition',['../structcom_1_1sun_1_1star_1_1chart2_1_1RelativePosition.html',1,'com::sun::star::chart2']]],
  ['relativesize',['RelativeSize',['../structcom_1_1sun_1_1star_1_1chart2_1_1RelativeSize.html',1,'com::sun::star::chart2']]],
  ['remoteaccesscontentprovider',['RemoteAccessContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1RemoteAccessContentProvider.html',1,'com::sun::star::ucb']]],
  ['remotecontentprovideracceptor',['RemoteContentProviderAcceptor',['../servicecom_1_1sun_1_1star_1_1ucb_1_1RemoteContentProviderAcceptor.html',1,'com::sun::star::ucb']]],
  ['remotecontentproviderchangeevent',['RemoteContentProviderChangeEvent',['../structcom_1_1sun_1_1star_1_1ucb_1_1RemoteContentProviderChangeEvent.html',1,'com::sun::star::ucb']]],
  ['remoteproxycontentprovider',['RemoteProxyContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1RemoteProxyContentProvider.html',1,'com::sun::star::ucb']]],
  ['renderdescriptor',['RenderDescriptor',['../servicecom_1_1sun_1_1star_1_1view_1_1RenderDescriptor.html',1,'com::sun::star::view']]],
  ['renderoptions',['RenderOptions',['../servicecom_1_1sun_1_1star_1_1view_1_1RenderOptions.html',1,'com::sun::star::view']]],
  ['renderstate',['RenderState',['../structcom_1_1sun_1_1star_1_1rendering_1_1RenderState.html',1,'com::sun::star::rendering']]],
  ['replacedescriptor',['ReplaceDescriptor',['../servicecom_1_1sun_1_1star_1_1util_1_1ReplaceDescriptor.html',1,'com::sun::star::util']]],
  ['reportcomponenthandler',['ReportComponentHandler',['../servicecom_1_1sun_1_1star_1_1report_1_1inspection_1_1ReportComponentHandler.html',1,'com::sun::star::report::inspection']]],
  ['reportcontrolformat',['ReportControlFormat',['../servicecom_1_1sun_1_1star_1_1report_1_1ReportControlFormat.html',1,'com::sun::star::report']]],
  ['reportcontrolmodel',['ReportControlModel',['../servicecom_1_1sun_1_1star_1_1report_1_1ReportControlModel.html',1,'com::sun::star::report']]],
  ['reportdefinition',['ReportDefinition',['../servicecom_1_1sun_1_1star_1_1report_1_1ReportDefinition.html',1,'com::sun::star::report']]],
  ['reportdesign',['ReportDesign',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ReportDesign.html',1,'com::sun::star::sdb']]],
  ['reportengine',['ReportEngine',['../servicecom_1_1sun_1_1star_1_1report_1_1ReportEngine.html',1,'com::sun::star::report']]],
  ['reports',['Reports',['../servicecom_1_1sun_1_1star_1_1sdb_1_1Reports.html',1,'com::sun::star::sdb']]],
  ['repository',['Repository',['../servicecom_1_1sun_1_1star_1_1rdf_1_1Repository.html',1,'com::sun::star::rdf']]],
  ['repositoryexception',['RepositoryException',['../exceptioncom_1_1sun_1_1star_1_1rdf_1_1RepositoryException.html',1,'com::sun::star::rdf']]],
  ['resourceid',['ResourceId',['../servicecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1ResourceId.html',1,'com::sun::star::drawing::framework']]],
  ['restartrequiredexception',['RestartRequiredException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1RestartRequiredException.html',1,'com::sun::star::java']]],
  ['resultcolumn',['ResultColumn',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ResultColumn.html',1,'com::sun::star::sdb']]],
  ['resultevent',['ResultEvent',['../structcom_1_1sun_1_1star_1_1sheet_1_1ResultEvent.html',1,'com::sun::star::sheet']]],
  ['resultset',['ResultSet',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1ResultSet.html',1,'com::sun::star::sdbcx']]],
  ['resultset',['ResultSet',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ResultSet.html',1,'com::sun::star::sdb']]],
  ['resultset',['ResultSet',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html',1,'com::sun::star::sdbc']]],
  ['resultsetexception',['ResultSetException',['../exceptioncom_1_1sun_1_1star_1_1ucb_1_1ResultSetException.html',1,'com::sun::star::ucb']]],
  ['revision',['Revision',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Revision.html',1,'com::sun::star::text::textfield::docinfo']]],
  ['revisiontag',['RevisionTag',['../structcom_1_1sun_1_1star_1_1util_1_1RevisionTag.html',1,'com::sun::star::util']]],
  ['rgbcolor',['RGBColor',['../structcom_1_1sun_1_1star_1_1rendering_1_1RGBColor.html',1,'com::sun::star::rendering']]],
  ['richtextcontrol',['RichTextControl',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1RichTextControl.html',1,'com::sun::star::form::component']]],
  ['roadmapitem',['RoadmapItem',['../servicecom_1_1sun_1_1star_1_1awt_1_1RoadmapItem.html',1,'com::sun::star::awt']]],
  ['rotationdescriptor',['RotationDescriptor',['../servicecom_1_1sun_1_1star_1_1drawing_1_1RotationDescriptor.html',1,'com::sun::star::drawing']]],
  ['rowchangeevent',['RowChangeEvent',['../structcom_1_1sun_1_1star_1_1sdb_1_1RowChangeEvent.html',1,'com::sun::star::sdb']]],
  ['rowschangeevent',['RowsChangeEvent',['../structcom_1_1sun_1_1star_1_1sdb_1_1RowsChangeEvent.html',1,'com::sun::star::sdb']]],
  ['rowset',['RowSet',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html',1,'com::sun::star::sdbc']]],
  ['rowset',['RowSet',['../servicecom_1_1sun_1_1star_1_1sdb_1_1RowSet.html',1,'com::sun::star::sdb']]],
  ['rowsetvetoexception',['RowSetVetoException',['../exceptioncom_1_1sun_1_1star_1_1sdb_1_1RowSetVetoException.html',1,'com::sun::star::sdb']]],
  ['rule',['Rule',['../structcom_1_1sun_1_1star_1_1ucb_1_1Rule.html',1,'com::sun::star::ucb']]],
  ['ruleset',['RuleSet',['../structcom_1_1sun_1_1star_1_1ucb_1_1RuleSet.html',1,'com::sun::star::ucb']]],
  ['ruleterm',['RuleTerm',['../structcom_1_1sun_1_1star_1_1ucb_1_1RuleTerm.html',1,'com::sun::star::ucb']]],
  ['runtimeexception',['RuntimeException',['../exceptioncom_1_1sun_1_1star_1_1uno_1_1RuntimeException.html',1,'com::sun::star::uno']]],
  ['runtimepermission',['RuntimePermission',['../structcom_1_1sun_1_1star_1_1security_1_1RuntimePermission.html',1,'com::sun::star::security']]]
];

==> libreoffice-fresh-sdk-5.3.4-1-armv6h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/classes_11.js <==
var searchData=
[
  ['radiobutton',['RadioButton',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1RadioButton.html',1,'RadioButton'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1RadioButton.html',1,'RadioButton']]],
  ['rangehighlighter',['RangeHighlighter',['../servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1RangeHighlighter.html',1,'com::sun::star::chart2::data']]],
  ['rangehighlightlistener',['RangeHighlightListener',['../servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1RangeHighlightListener.html',1,'com::sun::star::chart2::data']]],
  ['rangeselectionarguments',['RangeSelectionArguments',['../servicecom_1_1sun_1_1star_1_1sheet_1_1RangeSelectionArguments.html',1,'com::sun::star::sheet']]],
  ['rangeselectionevent',['RangeSelectionEvent',['../structcom_1_1sun_1_1star_1_1sheet_1_1RangeSelectionEvent.html',1,'com::sun::star::sheet']]],
  ['readonlyaccess',['ReadOnlyAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1ReadOnlyAccess.html',1,'com::sun::star::configuration']]],
  ['readwriteaccess',['ReadWriteAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1ReadWriteAccess.html',1,'com::sun::star::configuration']]],
  ['realbeziersegment2d',['RealBezierSegment2D',['../structcom_1_1sun_1_1star_1_1geometry_1_1RealBezierSegment2D.html',1,'com::sun::star::geometry']]],
  ['realpoint2d',['RealPoint2D',['../structcom_1_1sun_1_1star_1_1geometry_1_1RealPoint2D.html',1,'com::sun::star::geometry']]],
  ['realrectangle2d',['RealRectangle2D',['../structcom_1_1sun_1_1star_1_1geometry_1_1RealRectangle2D.html',1,'com::sun::star::geometry']]],
  ['realrectangle3d',['RealRectangle3D',['../structcom_1_1sun_1_1star_1_1geometry_1_1RealRectangle3D.html',1,'com::sun::star::geometry']]],
  ['realsize2d',['RealSize2D',['../structcom_1_1sun_1_1star_1_1geometry_1_1RealSize2D.html',1,'com::sun::star::geometry']]],
  ['recentfunctions',['RecentFunctions',['../servicecom_1_1sun_1_1star_1_1sheet_1_1RecentFunctions.html',1,'com::sun::star::sheet']]],
  ['recipientinfo',['RecipientInfo',['../structcom_1_1sun_1_1star_1_1ucb_1_1RecipientInfo.html',1,'com::sun::star::ucb']]],
  ['rectangle',['Rectangle',['../structcom_1_1sun_1_1star_1_1awt_1_1Rectangle.html',1,'com::sun::star::awt']]],
  ['rectangleshape',['RectangleShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1RectangleShape.html',1,'com::sun::star::drawing']]],
  ['redlineportion',['RedlinePortion',['../servicecom_1_1sun_1_1star_1_1text_1_1RedlinePortion.html',1,'com::sun::star::text']]],
  ['referencecolumn',['ReferenceColumn',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1ReferenceColumn.html',1,'com::sun::star::sdbcx']]],
  ['referencemark',['ReferenceMark',['../servicecom_1_1sun_1_1star_1_1text_1_1ReferenceMark.html',1,'com::sun::star::text']]],
  ['referencemarks',['ReferenceMarks',['../servicecom_1_1sun_1_1star_1_1text_1_1ReferenceMarks.html',1,'com::sun::star::text']]],
  ['referencepageget',['ReferencePageGet',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ReferencePageGet.html',1,'com::sun::star::text::textfield']]],
  ['referencepageset',['ReferencePageSet',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ReferencePageSet.html',1,'com::sun::star::text::textfield']]],
  ['registryservicemanager',['RegistryServiceManager',['../servicecom_1_1sun_1_1star_1_1lang_1_1RegistryServiceManager.html',1,'com::sun::star::lang']]],
  ['regressioncurve',['RegressionCurve',['../servicecom_1_1sun_1_1star_1_1chart2_1_1RegressionCurve.html',1,'com::sun::star::chart2']]],
  ['regressioncurveequation',['RegressionCurveEquation',['../servicecom_1_1sun_1_1star_1_1chart2_1_1RegressionCurveEquation.html',1,'com::sun::star::chart2']]],
  ['regressionequation',['RegressionEquation',['../servicecom_1_1sun_1_1star_1_1chart2_1_1RegressionEquation.html',1,'com::sun::star::chart2']]],
  ['relationdesign',['RelationDesign',['../servicecom_1_1sun_1_1star_1_1sdb_1_1RelationDesign.html',1,'com::sun::star::sdb']]],
  ['relativeposition',['RelativePosition',['../structcom_1_1sun_1_1star_1_1chart2_1_1RelativePosition.html',1,'com::sun::star::chart2']]],
  ['relativesize',['RelativeSize',['../structcom_1_1sun_1_1star_1_1chart2_1_1RelativeSize.html',1,'com::sun::star::chart2']]],
  ['remoteaccesscontentprovider',['RemoteAccessContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1RemoteAccessContentProvider.html',1,'com::sun::star::ucb']]],
  ['remotecontentprovideracceptor',['RemoteContentProviderAcceptor',['../servicecom_1_1sun_1_1star_1_1ucb_1_1RemoteContentProviderAcceptor.html',1,'com::sun::star::ucb']]],
  ['remotecontentproviderchangeevent',['RemoteContentProviderChangeEvent',['../structcom_1_1sun_1_1star_1_1ucb_1_1RemoteContentProviderChangeEvent.html',1,'com::sun::star::ucb']]],
  ['remoteproxycontentprovider',['RemoteProxyContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1RemoteProxyContentProvider.html',1,'com::sun::star::ucb']]],
  ['renderdescriptor',['RenderDescriptor',['../servicecom_1_1sun_1_1star_1_1view_1_1RenderDescriptor.html',1,'com::sun::star::view']]],
  ['renderoptions',['RenderOptions',['../servicecom_1_1sun_1_1star_1_1view_1_1RenderOptions.html',1,'com::sun::star::view']]],
  ['renderstate',['RenderState',['../structcom_1_1sun_1_1star_1_1rendering_1_1RenderState.html',1,'com::sun::star::rendering']]],
  ['replacedescriptor',['ReplaceDescriptor',['../servicecom_1_1sun_1_1star_1_1util_1_1ReplaceDescriptor.html',1,'com::sun::star::util']]],
  ['reportcomponenthandler',['ReportComponentHandler',['../servicecom_1_1sun_1_1star_1_1report_1_1inspection_1_1ReportComponentHandler.html',1,'com::sun::star::report::inspection']]],
  ['reportcontrolformat',['ReportControlFormat',['../servicecom_1_1sun_1_1star_1_1report_1_1ReportControlFormat.html',1,'com::sun::star::report']]],
  ['reportcontrolmodel',['ReportControlModel',['../servicecom_1_1sun_1_1star_1_1report_1_1ReportControlModel.html',1,'com::sun::star::report']]],
  ['reportdefinition',['ReportDefinition',['../servicecom_1_1sun_1_1star_1_1report_1_1ReportDefinition.html',1,'com::sun::star::report']]],
  ['reportdesign',['ReportDesign',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ReportDesign.html',1,'com::sun::star::sdb']]],
  ['reportengine',['ReportEngine',['../servicecom_1_1sun_1_1star_1_1report_1_1ReportEngine.html',1,'com::sun::star::report']]],
  ['reports',['Reports',['../servicecom_1_1sun_1_1star_1_1sdb_1_1Reports.html',1,'com::sun::star::sdb']]],
  ['repository',['Repository',['../servicecom_1_1sun_1_1star_1_1rdf_1_1Repository.html',1,'com::sun::star::rdf']]],
  ['repositoryexception',['RepositoryException',['../exceptioncom_1_1sun_1_1star_1_1rdf_1_1RepositoryException.html',1,'com::sun::star::rdf']]],
  ['resourceid',['ResourceId',['../servicecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1ResourceId.html',1,'com::sun::star::drawing::framework']]],
  ['restartrequiredexception',['RestartRequiredException',['../exceptioncom_1_1sun_1_1star_1_1java_1_1RestartRequiredException.html',1,'com::sun::star::java']]],
  ['resultcolumn',['ResultColumn',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ResultColumn.html',1,'com::sun::star::sdb']]],
  ['resultevent',['ResultEvent',['../structcom_1_1sun_1_1star_1_1sheet_1_1ResultEvent.html',1,'com::sun::star::sheet']]],
  ['resultset',['ResultSet',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ResultSet.html',1,'ResultSet'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html',1,'ResultSet'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1ResultSet.html',1,'ResultSet']]],
  ['resultsetexception',['ResultSetException',['../exceptioncom_1_1sun_1_1star_1_1ucb_1_1ResultSetException.html',1,'com::sun::star::ucb']]],
  ['revision',['Revision',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Revision.html',1,'com::sun::star::text::textfield::docinfo']]],
  ['revisiontag',['RevisionTag',['../structcom_1_1sun_1_1star_1_1util_1_1RevisionTag.html',1,'com::sun::star::util']]],
  ['rgbcolor',['RGBColor',['../structcom_1_1sun_1_1star_1_1rendering_1_1RGBColor.html',1,'com::sun::star::rendering']]],
  ['richtextcontrol',['RichTextControl',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1RichTextControl.html',1,'com::sun::star::form::component']]],
  ['roadmapitem',['RoadmapItem',['../servicecom_1_1sun_1_1star_1_1awt_1_1RoadmapItem.html',1,'com::sun::star::awt']]],
  ['rotationdescriptor',['RotationDescriptor',['../servicecom_1_1sun_1_1star_1_1drawing_1_1RotationDescriptor.html',1,'com::sun::star::drawing']]],
  ['rowchangeevent',['RowChangeEvent',['../structcom_1_1sun_1_1star_1_1sdb_1_1RowChangeEvent.html',1,'com::sun::star::sdb']]],
  ['rowschangeevent',['RowsChangeEvent',['../structcom_1_1sun_1_1star_1_1sdb_1_1RowsChangeEvent.html',1,'com::sun::star::sdb']]],
  ['rowset',['RowSet',['../servicecom_1_1sun_1_1star_1_1sdb_1_1RowSet.html',1,'RowSet'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1RowSet.html',1,'RowSet']]],
  ['rowsetvetoexception',['RowSetVetoException',['../exceptioncom_1_1sun_1_1star_1_1sdb_1_1RowSetVetoException.html',1,'com::sun::star::sdb']]],
  ['rule',['Rule',['../structcom_1_1sun_1_1star_1_1ucb_1_1Rule.html',1,'com::sun::star::ucb']]],
  ['ruleset',['RuleSet',['../structcom_1_1sun_1_1star_1_1ucb_1_1RuleSet.html',1,'com::sun::star::ucb']]],
  ['ruleterm',['RuleTerm',['../structcom_1_1sun_1_1star_1_1ucb_1_1RuleTerm.html',1,'com::sun::star::ucb']]],
  ['runtimeexception',['RuntimeException',['../exceptioncom_1_1sun_1_1star_1_1uno_1_1RuntimeException.html',1,'com::sun::star::uno']]],
  ['runtimepermission',['RuntimePermission',['../structcom_1_1sun_1_1star_1_1security_1_1RuntimePermission.html',1,'com::sun::star::security']]]
];
